Learn R Programming

matR (version 0.9.1)

BIOMmerge: Merge BIOM data

Description

Merge two objects of class biom, maintaining metadata and other class structure.

Usage

# S3 method for biom
merge(x, y, ...)

Arguments

x

an object (biom)

y

an object (biom)

unused

Value

A biom object resulting from merging x and y.

Details

Complete technical documentation is forthcoming. For the current preliminary release, please refer to the examples provided.

See Also

BIOM.utils::biom

Examples

Run this code
# NOT RUN {
####  merging requires only that all colnames be unique, so nonsense can be performed
merge (xx1, xx4)

####  a more likely example, based on applying different normalizations
aa <- transform (xx4 [,1:8], t_Threshold, t_Log)
bb <- transform (xx4 [,9:16], t_Threshold=list(entry.min=5), t_Log)
xx4_norm <- merge (aa, bb)
# }

Run the code above in your browser using DataLab