Learn R Programming

matR (version 0.9)

BIOMrename: Change row and column identifiers of BIOM data

Description

Change the dimnames (BIOM row and column ids) of an object of class biom.

Usage

"dimnames"(x) <- value

Arguments

x
an object (biom)
value
new row and column identifiers (list of character)

Value

The argument x with updated row and column ids (that is, dimnames).

Details

Complete technical documentation is forthcoming. For the current preliminary release, please refer to the examples provided.

See Also

BIOM.utils::biom, BIOM.utils::dimnames.biom

Examples

Run this code
####  even if not particularly useful, this is allowed
yy <- xx4
dimnames (yy) <- list (letters [1:nrow(yy)], LETTERS [1:ncol(yy)])

####  more useful: renaming columns by codes taken from metadata
colnames (yy) <- columns (yy, "sample.data.sample_name")

Run the code above in your browser using DataLab